@@ -100,7 +100,6 @@ struct GsdWacomManagerPrivate
         guint start_idle_id;
         GsdDeviceManager *device_manager;
         guint device_added_id;
-        guint device_changed_id;
         guint device_removed_id;
         GHashTable *devices; /* key = GdkDevice, value = GsdWacomDevice */
         GnomeRRScreen *rr_screen;
@@ -109,7 +108,6 @@ struct GsdWacomManagerPrivate
         GsdShell *shell_proxy;
 
         GsdDeviceMapper *device_mapper;
-        guint mapping_changed_id;
 
         /* button capture */
         GdkScreen *screen;
@@ -263,22 +261,6 @@ wacom_set_property (GsdWacomDevice *device,
 	xdevice_close (xdev);
 }
 
-static void
-set_rotation (GsdWacomDevice   *device,
-	      GsdWacomRotation	rotation)
-{
-	gchar rot = rotation;
-	PropertyHelper property = {
-		.name = "Wacom Rotation",
-		.nitems = 1,
-		.format = 8,
-		.type = XA_INTEGER,
-		.data.c = &rot
-	};
-
-	wacom_set_property (device, &property);
-}
-
 static void
 set_pressurecurve (GsdWacomDevice *device,
                    GVariant       *value)
@@ -821,7 +803,7 @@ set_wacom_settings (GsdWacomManager *manager,
 		for (l = buttons; l != NULL; l = l->next) {
 			GsdWacomTabletButton *button = l->data;
 			if (button->has_oled) {
-				g_signal_connect (G_OBJECT (button->settings), "changed::oled-label",
+				g_signal_connect (G_OBJECT (button->settings), "changed::" OLED_LABEL,
 						  G_CALLBACK (gsettings_oled_changed), button);
 				g_object_set_data (G_OBJECT (button->settings), "parent-device", device);
 			}
@@ -833,8 +815,6 @@ set_wacom_settings (GsdWacomManager *manager,
 		grab_button (id, TRUE, manager->priv->screen);
 
 		return;
-	} else {
-		set_rotation (device, g_settings_get_enum (settings, KEY_ROTATION));
 	}
 
 	set_absolute (device, g_settings_get_boolean (settings, KEY_IS_ABSOLUTE));
@@ -863,10 +843,9 @@ wacom_settings_changed (GSettings      *settings,
 	type = gsd_wacom_device_get_device_type (device);
 
 	if (g_str_equal (key, KEY_ROTATION)) {
+                /* Real device rotation is handled in GsdDeviceMapper */
 		if (type == WACOM_TYPE_PAD)
 			update_pad_leds (device);
-                else
-                        set_rotation (device, g_settings_get_enum (settings, key));
 	} else if (g_str_equal (key, KEY_TOUCH)) {
 	        if (type == WACOM_TYPE_TOUCH)
 			set_touch (device, g_settings_get_boolean (settings, key));
@@ -1126,30 +1105,6 @@ device_added_cb (GsdDeviceManager *device_manager,
 
 	for (i = 0; i < n_gdk_devices; i++)
 		gsd_wacom_manager_add_gdk_device (manager, devices[i]);
-
-	g_free (devices);
-}
-
-static void
-device_changed_cb (GsdDeviceManager *device_manager,
-		   GsdDevice	    *gsd_device,
-		   GsdWacomManager  *manager)
-{
-	GdkDevice **devices;
-	guint i, n_gdk_devices;
-
-	if (gnome_settings_is_wayland ())
-		return;
-
-	devices = gsd_x11_device_manager_get_gdk_devices (GSD_X11_DEVICE_MANAGER (device_manager),
-							  gsd_device, &n_gdk_devices);
-
-	for (i = 0; i < n_gdk_devices; i++) {
-		if (!g_hash_table_lookup (manager->priv->devices, devices[i]))
-			gsd_wacom_manager_add_gdk_device (manager, devices[i]);
-	}
-
-	g_free (devices);
 }
 
 static void
@@ -1187,8 +1142,6 @@ device_removed_cb (GsdDeviceManager *device_manager,
 
 	for (i = 0; i < n_gdk_devices; i++)
 		gsd_wacom_manager_remove_gdk_device (manager, devices[i]);
-
-	g_free (devices);
 }
 
 static GsdWacomDevice *
@@ -1559,8 +1512,6 @@ set_devicepresence_handler (GsdWacomManager *manager)
         device_manager = gsd_device_manager_get ();
         manager->priv->device_added_id = g_signal_connect (G_OBJECT (device_manager), "device-added",
                                                            G_CALLBACK (device_added_cb), manager);
-        manager->priv->device_changed_id = g_signal_connect (G_OBJECT (device_manager), "device-changed",
-                                                             G_CALLBACK (device_changed_cb), manager);
         manager->priv->device_removed_id = g_signal_connect (G_OBJECT (device_manager), "device-removed",
                                                              G_CALLBACK (device_removed_cb), manager);
         manager->priv->device_manager = device_manager;
@@ -1572,40 +1523,6 @@ gsd_wacom_manager_init (GsdWacomManager *manager)
         manager->priv = GSD_WACOM_MANAGER_GET_PRIVATE (manager);
 }
 
-static void
-device_mapping_changed (GsdDeviceMapper *mapper,
-                        GsdDevice       *gsd_device,
-                        GsdWacomManager *manager)
-{
-	guint i, n_gdk_devices;
-	GdkDevice **devices;
-
-	if (gnome_settings_is_wayland ())
-		return;
-
-	devices = gsd_x11_device_manager_get_gdk_devices (GSD_X11_DEVICE_MANAGER (manager->priv->device_manager),
-							  gsd_device, &n_gdk_devices);
-
-	for (i = 0; i < n_gdk_devices; i++) {
-                GsdWacomDevice *wacom_device;
-                GsdWacomDeviceType type;
-                GSettings *settings;
-
-                wacom_device = g_hash_table_lookup (manager->priv->devices, devices[i]);
-
-                if (!wacom_device)
-                        continue;
-
-                settings = gsd_wacom_device_get_settings (wacom_device);
-                type = gsd_wacom_device_get_device_type (wacom_device);
-
-                if (type != WACOM_TYPE_TOUCH && type != WACOM_TYPE_PAD)
-                        set_keep_aspect (wacom_device, g_settings_get_boolean (settings, KEY_KEEP_ASPECT));
-        }
-
-        g_free (devices);
-}
-
 static gboolean
 gsd_wacom_manager_idle_cb (GsdWacomManager *manager)
 {
@@ -1615,10 +1532,6 @@ gsd_wacom_manager_idle_cb (GsdWacomManager *manager)
 
         manager->priv->device_mapper = gsd_device_mapper_get ();
 
-        manager->priv->mapping_changed_id =
-                g_signal_connect (manager->priv->device_mapper, "device-changed",
-                                  G_CALLBACK (device_mapping_changed), manager);
-
         manager->priv->warned_devices = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
         manager->priv->devices = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_object_unref);
@@ -1828,7 +1741,6 @@ gsd_wacom_manager_stop (GsdWacomManager *manager)
 
         if (p->device_manager != NULL) {
                 g_signal_handler_disconnect (p->device_manager, p->device_added_id);
-                g_signal_handler_disconnect (p->device_manager, p->device_changed_id);
                 g_signal_handler_disconnect (p->device_manager, p->device_removed_id);
                 p->device_manager = NULL;
         }
@@ -1871,11 +1783,6 @@ gsd_wacom_manager_finalize (GObject *object)
 
         gsd_wacom_manager_stop (wacom_manager);
 
-        if (wacom_manager->priv->mapping_changed_id) {
-                g_signal_handler_disconnect (wacom_manager->priv->device_mapper,
-                                             wacom_manager->priv->mapping_changed_id);
-        }
-
         if (wacom_manager->priv->warned_devices) {
                 g_hash_table_destroy (wacom_manager->priv->warned_devices);
                 wacom_manager->priv->warned_devices = NULL;
